<p align="center">
  <img src="https://imgur.com/L2IZ2MH.png" width="120" alt="clickgen" />
  <br />
  <img src="https://i.imgur.com/TeItlMh.png" width="200" />
</p>

<p align="center">
  X11 & Windows Cursor API 👷
</p>

<p align="center">
  <img alt="Downloads" src="https://github.com/KaizIqbal/clickgen/workflows/build/badge.svg?branch=master&event=push" />
</p>
